==> CGFBApp-1.0.7.tar.gz: CGFBApp/function.admin_fbsettings_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_fbsettings_tab'));
$smarty->assign('fb_appid',$this->GetPreference('fb_appid'));
$smarty->assign('fb_appsecret',$this->GetPreference('fb_appsecret'));
$smarty->assign('formend',$this->CreateFormEnd());

$perms = array('publish_stream','create_event','rsvp_event','sms','offline_access','publish_checkins',
	       'user_about_me','user_activities','user_birthday','user_education_history','user_events',
	       'user_groups','user_hometown','user_interests','user_likes','user_location','user_notes','user_online_presence',
	       'user_photo_video_tags','user_photos','user_relationships','user_relationship_details','user_religion_politics',
	       'user_status','user_videos','user_website','user_work_history','email','read_friendlists','read_insights',
	       'read_mailbox','reqd_requests','read_stream','user_checkins','friends_aboutme','friends_activities','friends_birthday','friends_education_history',
	       'friends_events','friends_groups','friends_hometown','friends_interests','friends_likes','friends_location','friends_notes','friends_online_presense',
	       'friends_photo_video_tags','friends_relationships','friends_relationship_details','friends_religion_politics','friends_videos','friends_website',
	       'friends_work_history','manage_friendlists','friends_checkins');
$perms = array_combine($perms,$perms);
$smarty->assign('perm_list',$perms);
$tmp = $this->GetPreference('fb_perms');
if( $tmp )
  {
    $tmp = explode(',',$tmp);
  }
$smarty->assign('fb_perms',$tmp);

echo $this->ProcessTemplate('admin_fbsettings_tab.tpl');

#
# EOF
#
?>

==> CGFBApp-1.0.9.tar.gz: CGFBApp/function.admin_fbsettings_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

$smarty->assign('formstart',$this->CGCreateFormStart($id,'admin_fbsettings_tab'));
$smarty->assign('fb_appid',$this->GetPreference('fb_appid'));
$smarty->assign('fb_appsecret',$this->GetPreference('fb_appsecret'));
$smarty->assign('fb_pageid',$this->GetPreference('fb_pageid'));
$smarty->assign('formend',$this->CreateFormEnd());

$perms = array('publish_stream','publish_actions','create_event','rsvp_event','sms', // offline_access
	       'user_about_me','user_activities','user_birthday','user_education_history','user_events',
	       'user_groups','user_hometown','user_interests','user_likes','user_location','user_notes','user_online_presence',
	       'user_photo_video_tags','user_photos','user_relationships','user_relationship_details','user_religion_politics',
	       'user_status','user_videos','user_website','user_work_history','email','read_friendlists','read_insights',
	       'read_mailbox','reqd_requests','read_stream','user_checkins','friends_aboutme','friends_activities','friends_birthday',
	       'friends_education_history','friends_events','friends_groups','friends_hometown','friends_interests','friends_likes',
	       'friends_location','friends_notes','friends_online_presense','friends_photo_video_tags','friends_relationships',
	       'friends_relationship_details','friends_religion_politics','friends_videos','friends_website',
	       'friends_work_history','manage_pages','manage_friendlists','friends_checkins');

$perms = array_combine($perms,$perms);
$smarty->assign('perm_list',$perms);
$tmp = $this->GetPreference('fb_perms','publish_stream');
if( $tmp ) $tmp = explode(',',$tmp);
$smarty->assign('fb_perms',$tmp);

echo $this->ProcessTemplate('admin_fbsettings_tab.tpl');

#
# EOF
#
?>
